# frozen_string_literal: true

# Released under the MIT License.
# Copyright, 2025, by Samuel Williams.

require_relative "format/version"
require_relative "format/count"
require_relative "format/ratio"
require_relative "format/decimal"
require_relative "format/title_case"
require_relative "format/snake_case"
require_relative "format/statistics"

module String::Format
end
